
```shell
alias ll='ls -lh'
alias l='ls -lha'
alias ..='cd ..'
alias axel='axel -n 100'
alias free="free -h"
alias df="df -h"
alias vi="vim"
alias ~="cd ~"
alias sh="bash"

# pathes
alias cddow="cd ~/Downloads/;pwd"
alias cdh="cd ~;pwd"
alias cddoc="cd ~/Documents/;pwd"
alias cdmusic="cd ~/Music;pwd"
alias cdgitee="cd ~/Music/GiteProjects/"
alias cdgithub="cd ~/Music/GithubProjects/"

#alias jp="jupyter notebook --no-browser --allow-root >&1 &"
alias jp="jupyter notebook --no-browser"

#alias jl="jupyter lab --allow-root >&1 &"
alias jl="jupyter lab"

# start mongodb server
alias imongo="sudo /usr/local/mongodb/bin/mongod --dbpath=/usr/local/mongodb/data/db/"

```